from ....model.argument.option.option import Option

__all__ = ["HiddenOption"]


## It is Hidden in Help Page
class HiddenOption(Option):
    ...
